//
//  SettingsViewController.m
//  iAppsReview
//
//  Created by Kevin McNeish on 10/16/13.
//  Copyright (c) 2013 Oak Leaf Enterprises, Inc. All rights reserved.
//

#import "SettingsViewController.h"
#import "User.h"
#import "UserEntity.h"

@interface SettingsViewController ()

@end

@implementation SettingsViewController
{
	UserEntity *userEntity;
	BOOL isEditMode;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

	// Create the user business object and get the
	// settings from the UserEntity
	self.user = [[User alloc] init];
	userEntity = [self.user getUser];
	self.txtEMail.text = userEntity.email;
	self.txtPassword.text = userEntity.password;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)hideKeyboard:(id)sender {
	
	[self.view endEditing:YES];
}

- (IBAction)emailReturnKey:(id)sender {

	[self.txtPassword becomeFirstResponder];
}

- (IBAction)editToggle:(id)sender {

	if (isEditMode) {
		// Done!
		if (!userEntity) {
			userEntity = (UserEntity *)[self.user createEntity];
		}
		userEntity.email = self.txtEMail.text;
		userEntity.password = self.txtPassword.text;

		// temp values
		userEntity.userID = 1;
		userEntity.firstName = @"Kevin";
		userEntity.lastName = @"McNeish";

		// Save changes
		[self.user saveEntities];

		// Enable the login button
		self.btnLogin.enabled = YES;

		// Cancel edit mode
		[self cancelEditMode];
	}
	else {
		// Change the title of the button to Done
		self.navigationItem.rightBarButtonItem.title = @"Done";

		// Enable/Disable Done button
		[self setDoneEnabledValue:nil];

		// Hide the standard back button, display a cancel button
		self.navigationItem.hidesBackButton = YES;

		UIBarButtonItem *cancelBarButtonItem =
		[[UIBarButtonItem alloc] initWithTitle:@"Cancel"
										 style:UIBarButtonItemStylePlain target:self
										action:@selector(cancel)];

		self.navigationItem.leftBarButtonItem = cancelBarButtonItem;

		// Disable the buttons
		self.btnLogin.enabled = NO;
		self.btnSignUp.enabled = NO;
		self.btnFeedback.enabled = NO;

		// Enable user interaction in the text fields
		self.txtEMail.userInteractionEnabled = YES;
		self.txtPassword.userInteractionEnabled = YES;

		// Set focus to the email text field
		[self.txtEMail becomeFirstResponder];

		isEditMode = YES;
	}
}

- (IBAction)setDoneEnabledValue:(id)sender {
	
	self.navigationItem.rightBarButtonItem.enabled =
		[self isLoginReady];
}

- (void)cancelEditMode
{
	// Change the title of the butkton to Edit and enable
	self.navigationItem.rightBarButtonItem.title = @"Edit";
	self.navigationItem.rightBarButtonItem.enabled = YES;

	// Hide the Cancel button, display standard back button
	self.navigationItem.leftBarButtonItem = nil;
	self.navigationItem.hidesBackButton = NO;

	// Enable the buttons
	self.btnSignUp.enabled = YES;
	self.btnFeedback.enabled = YES;

	// Disable user interaction in text fields
	self.txtEMail.userInteractionEnabled = NO;
	self.txtPassword.userInteractionEnabled = NO;

	isEditMode = NO;
}

- (void)cancel
{
	self.txtEMail.text = userEntity.email;
	self.txtPassword.text = userEntity.password;
	[self cancelEditMode];
}

- (BOOL)isLoginReady
{
	return self.txtEMail.text.length > 0 && self.txtPassword.text.length > 0;
}

@end
